@@ -105,7 +105,12 @@ class B2UploadSettings(__Extension):
         self.application_key = application_key
         self.bucket_id = bucket_id
         self.cdn_url = cdn_url if cdn_url[-1:] == "/" else cdn_url + "/"
-        self.pathway = pathway if pathway[-1:] == "/" else pathway + "/"
+
+        if pathway[-1:] == "/":
+            self.pathway = pathway[:-1]
+
+        if pathway[0] == "/":
+            self.pathway = pathway[1:]
 
 
 class LocalUploadSettings(__Extension):
